﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Airbus
{
    public partial class FormPlaneConfig : Form
    {
        //переменная-выбранная машина
        DrawningAirbus _plane = null;

        //событие
        private event PlaneDelegate EventAddPlane;

        //конструктор
        public FormPlaneConfig()
        {
            InitializeComponent();
            panelBlack.MouseDown += PanelColor_MouseDown;
            panelPurple.MouseDown += PanelColor_MouseDown;
            panelGray.MouseDown += PanelColor_MouseDown;
            panelGreen.MouseDown += PanelColor_MouseDown;
            panelRed.MouseDown += PanelColor_MouseDown;
            panelWhite.MouseDown += PanelColor_MouseDown;
            panelYellow.MouseDown += PanelColor_MouseDown;
            panelBlue.MouseDown += PanelColor_MouseDown;
        }

        //отрисовка самолёт
        private void DrawPlane()
        {
            Bitmap bmp = new(pictureBoxObject.Width, pictureBoxObject.Height);
            Graphics gr = Graphics.FromImage(bmp);
            _plane?.SetPosition(5, 5, pictureBoxObject.Width, pictureBoxObject.Height);
            _plane?.DrawTransport(gr);
            pictureBoxObject.Image = bmp;
        }

        //добавление события
        public void AddEvent(PlaneDelegate ev)
        {
            if(EventAddPlane == null)
            {
                EventAddPlane = new PlaneDelegate(ev);
            } 
            else
            {
                EventAddPlane += ev;
            }
        }

        private void LabelObject_MouseDown(object sender, MouseEventArgs e)
        {
            (sender as Label).DoDragDrop((sender as Label).Name, DragDropEffects.Move | DragDropEffects.Copy);
        }

        //проверка получаемой информации (ее типа на соответствие требуемому)
        private void PanelObject_DragEnter(object sender, DragEventArgs e)
        {
            if (e.Data.GetDataPresent(DataFormats.Text))
            {
                e.Effect = DragDropEffects.Copy;
            }
            else
            {
                e.Effect = DragDropEffects.None;
            }
        }

        //действия при приеме перетаскиваемой информации
        private void PanelObject_DragDrop(object sender, DragEventArgs e)
        {
            switch (e.Data.GetData(DataFormats.Text).ToString())
            {
                case "labelSimpleObject":
                    _plane = new DrawningAirbus((int)numericUpDownSpeed.Value, (int)numericUpDownWeight.Value, labelBaseColor.BackColor);
                    break;
                case "labelModifiedObject":
                    _plane = new DrawningSuperAirbus((int)numericUpDownSpeed.Value, (int)numericUpDownWeight.Value, labelBaseColor.BackColor, labelAddColor.BackColor, 
                        checkBoxAddСompartment.Checked, checkBoxAddEngine.Checked);
                    break;
            }

            DrawPlane();
        }

        //отправляем цвет с панели
        private void PanelColor_MouseDown(object sender, MouseEventArgs e)
        {
            (sender as Control).DoDragDrop((sender as Control).Name, DragDropEffects.Move | DragDropEffects.Copy);
        }

        //проверка получаемой информации (её типа на соответсвие требуемому)
        private void LabelBaseColor_DragEnter(object sender, DragEventArgs e)
        {
            if (e.Data.GetDataPresent(DataFormats.Text))
            {
                e.Effect = DragDropEffects.Copy;
            }
            else
            {
                e.Effect = DragDropEffects.None;
            }
        }

        //принимаем основной цвет
        private void LabelBaseColor_DragDrop(object sender, DragEventArgs e)
        {
            switch (e.Data.GetData(DataFormats.Text).ToString())
            {
                case "panelRed":
                    labelBaseColor.BackColor = Color.Red;
                    break;
                case "panelBlack":
                    labelBaseColor.BackColor = Color.Black;
                    break;
                case "panelGreen":
                    labelBaseColor.BackColor = Color.Green;
                    break;
                case "panelYellow":
                    labelBaseColor.BackColor = Color.Yellow;
                    break;
                case "panelBlue":
                    labelBaseColor.BackColor = Color.Blue;
                    break;
                case "panelPurple":
                    labelBaseColor.BackColor = Color.Purple;
                    break;
                case "panelGray":
                    labelBaseColor.BackColor = Color.DarkGray;
                    break;
                case "panelWhite":
                    labelBaseColor.BackColor = Color.White;
                    break;
            }
        }

        //проверка получаемой информации (её типа на соответсвие требуемому)
        private void LabelAddColor_DragEnter(object sender, DragEventArgs e)
        {
            if (e.Data.GetDataPresent(DataFormats.Text))
            {
                e.Effect = DragDropEffects.Copy;
            }
            else
            {
                e.Effect = DragDropEffects.None;
            }
        }

        //принимаем дополнительный цвет
        private void labelAddColor_DragDrop(object sender, DragEventArgs e)
        {
            switch (e.Data.GetData(DataFormats.Text).ToString())
            {
                case "panelRed":
                    labelAddColor.BackColor = Color.Red;
                    break;
                case "panelBlack":
                    labelAddColor.BackColor = Color.Black;
                    break;
                case "panelGreen":
                    labelAddColor.BackColor = Color.Green;
                    break;
                case "panelYellow":
                    labelAddColor.BackColor = Color.Yellow;
                    break;
                case "panelBlue":
                    labelAddColor.BackColor = Color.Blue;
                    break;
                case "panelPurple":
                    labelAddColor.BackColor = Color.Purple;
                    break;
                case "panelGray":
                    labelAddColor.BackColor = Color.DarkGray;
                    break;
                case "panelWhite":
                    labelAddColor.BackColor = Color.White;
                    break;
            }
        }

        //добавление машины
        private void ButtonAddObject_Click(object sender, EventArgs e)
        {
            EventAddPlane?.Invoke(_plane);
            Close();
        }

        //закрытие формы конфигурации
        private void ButtonCancel_Click(object sender, EventArgs e)
        {
            Close();
        }

        
    }
}
